==> tuia-commercial-center-api-1.0.2-hrd-20190912.054012-1-sources.jar: cn/com/duiba/tuia/commercial/center/api/remoteservice/commercial/plant/RemotePlantV5Service.java <==
package cn.com.duiba.tuia.commercial.center.api.remoteservice.commercial.plant;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.req.FinishMissionReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.LotteryDto;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.PlantDto;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.PropDto;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.req.PlantPropReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.req.ResetForTestReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.user.req.CommercialUserReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.user.req.PlantV5UserReq;

/**
 * RemotePlantV5Service
 *
 * @author huangruodan
 * @date 2019-07-21
 */

@AdvancedFeignClient
public interface RemotePlantV5Service {

    /**
     * 签到
     *
     * @param req 用户参数
     * @return 种红包所有信息
     * @throws BizException
     */
    PlantDto sign(PlantV5UserReq req) throws BizException;

    /**
     * 种红包
     *
     * @param req      用户参数
     * @return 用户信息、土地信息、种子仓库
     * @throws BizException
     */
    PlantDto plant(PlantV5UserReq req) throws BizException;

    /**
     * 采摘红包
     *
     * @return 用户信息，奖励信息
     * @throws BizException
     */
    PlantDto pick(PlantV5UserReq req) throws BizException;

    /**
     * 领取任务奖励
     *
     * @param req 用户参数、missionId 任务编号
     * @return 用户信息，奖励信息
     */
    PlantDto finishMission(FinishMissionReq req) throws BizException;



    /**
     * 用户使用道具，
     *
     * @param req landId,propTye,user
     * @return
     * @throws BizException
     */
    PropDto useProp(PlantPropReq req) throws BizException;

    /**
     * @param req
     * @return
     * @throws BizException
     */
    LotteryDto lotteryEveryday(PlantV5UserReq req) throws BizException;


    /**
     * @param req
     * @return
     * @throws BizException
     */
    int finishVat(CommercialUserReq req) throws BizException;

    /**
     * 换天接口
     * @param req deviceId、appId、date
     * @return
     * @throws BizException
     */
    Boolean resetForTest(ResetForTestReq req) throws BizException;

    void moveMandu(Integer limit, Integer size);
}

==> tuia-commercial-center-api-1.0.8-hrd-20191015.090947-4-sources.jar: cn/com/duiba/tuia/commercial/center/api/remoteservice/commercial/plant/RemotePlantV5Service.java <==
package cn.com.duiba.tuia.commercial.center.api.remoteservice.commercial.plant;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.req.FinishMissionReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.LotteryDto;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.PlantDto;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.PropDto;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.req.PlantPropReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.plant.req.ResetForTestReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.user.req.CommercialUserReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.user.req.FinishMoonRewardReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.user.req.PlantV5UserReq;

/**
 * RemotePlantV5Service
 *
 * @author huangruodan
 * @date 2019-07-21
 */

@AdvancedFeignClient
public interface RemotePlantV5Service {

    /**
     * 签到
     *
     * @param req 用户参数
     * @return 种红包所有信息
     * @throws BizException
     */
    PlantDto sign(PlantV5UserReq req) throws BizException;

    /**
     * 种红包
     *
     * @param req      用户参数
     * @return 用户信息、土地信息、种子仓库
     * @throws BizException
     */
    PlantDto plant(PlantV5UserReq req) throws BizException;

    /**
     * 采摘红包
     *
     * @return 用户信息，奖励信息
     * @throws BizException
     */
    PlantDto pick(PlantV5UserReq req) throws BizException;

    /**
     * 领取任务奖励
     *
     * @param req 用户参数、missionId 任务编号
     * @return 用户信息，奖励信息
     */
    PlantDto finishMission(FinishMissionReq req) throws BizException;



    /**
     * 用户使用道具，
     *
     * @param req landId,propTye,user
     * @return
     * @throws BizException
     */
    PropDto useProp(PlantPropReq req) throws BizException;

    /**
     * @param req
     * @return
     * @throws BizException
     */
    LotteryDto lotteryEveryday(PlantV5UserReq req) throws BizException;


    /**
     * @param req
     * @return
     * @throws BizException
     */
    int finishVat(CommercialUserReq req) throws BizException;

    /**
     * 换天接口
     * @param req deviceId、appId、date
     * @return
     * @throws BizException
     */
    Boolean resetForTest(ResetForTestReq req) throws BizException;

    /**
     * 领取月光宝盒奖励
     * @param rewardReq 用户参数、用户定制类型
     * @return 用户奖励数据
     * @throws BizException 业务异常
     */
    PlantDto finishMoonReward(FinishMoonRewardReq rewardReq) throws BizException;


    String updatePlantUser(Integer start, Integer size);
}
